==> alg-model-5.1.30-20201012.073056-1-sources.jar: cn/com/duiba/nezha/alg/model/DCVR.java <==
package cn.com.duiba.nezha.alg.model;

import cn.com.duiba.nezha.alg.common.util.AssertUtil;
import cn.com.duiba.nezha.alg.feature.coder.FeatureNewCoder;
import cn.com.duiba.nezha.alg.feature.vo.CodeResult;
import cn.com.duiba.nezha.alg.feature.vo.FeatureMapDo;
import cn.com.duiba.nezha.alg.model.enums.PredictResultType;
import cn.com.duiba.nezha.alg.model.tf.TFServingClient;
import com.alibaba.fastjson.JSON;
import org.slf4j.LoggerFactory;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class DCVR implements Serializable {
    private static final org.slf4j.Logger logger = LoggerFactory.getLogger(DCVR.class);
    private int PB_MAX_SIZE = 128;

    /**
     * 后端预估模型
     */
    private IModel dCvrModel;
    private IModel coderModel;

    /**
     *
     * 点击率预估深度学习TF-S-Client
     */
    private TFServingClient dcvrServingClient;

    public IModel getDCvrModel() {
        return dCvrModel;
    }

    public void setDCvrModel(IModel bCvrModel) {
        this.dCvrModel = dCvrModel;
    }

    public TFServingClient getDcvrServingClient() {
        return dcvrServingClient;
    }

    public void setDcvrServingClient(TFServingClient dcvrServingClient) {
        this.dcvrServingClient = dcvrServingClient;
    }


    /**
     * @param dcvrModel
     */
    public DCVR(IModel dcvrModel) {
        this.dCvrModel = dcvrModel;
    }

    public DCVR(IModel dCvrModel, IModel coderModel, TFServingClient dcvrServingClient) {
        this.dCvrModel = dCvrModel;
        this.coderModel = coderModel;
        this.dcvrServingClient = dcvrServingClient;
    }

    /**
     * 预估主接口
     *
     * @param featureMap
     * @return
     * @throws Exception
     */
    public <T> Map<PredictResultType, Map<T, Double>> predictDCvr(Map<T, FeatureMapDo> featureMap) throws Exception {
        Map<PredictResultType, Map<T, Double>> ret = new HashMap<>(PB_MAX_SIZE);

        Map<T, Double> dcvrMap = dCvrModel.predictsNew(featureMap);

        if (AssertUtil.isAllNotEmpty(dcvrMap)) {
            ret.put(PredictResultType.DCVR, dcvrMap);
        } else {
            ret = null;
        }

        return ret;
    }

    public <T> Map<PredictResultType, Map<T, Double>> predictDCvrWithTF(Map<T, FeatureMapDo> featureMap,TFServingClient dcvrServingClient) throws Exception {
        Map<PredictResultType, Map<T, Double>> ret = new HashMap<>(PB_MAX_SIZE);

        Map<T, Double> dcvrMap = coderModel.predictWithTFNew(featureMap, dcvrServingClient);

        if (AssertUtil.isAllNotEmpty(dcvrMap)) {
            ret.put(PredictResultType.DCVR, dcvrMap);
        } else {
            logger.warn(coderModel.getModelId() + ": dcvr fusing");
            dcvrMap = dCvrModel.predictsNew(featureMap);
            if (AssertUtil.isAllNotEmpty(dcvrMap)) {
                ret.put(PredictResultType.DCVR, dcvrMap);
            } else {
                ret = null;
            }
        }
        return ret;
    }


    public <T> Map<PredictResultType, Map<T, Double>> predictDCvrAndTF(Map<T, FeatureMapDo> featureMap)throws Exception{
        if(dcvrServingClient != null){
            return predictDCvrWithTF(featureMap,dcvrServingClient);
        }
        return predictDCvr(featureMap);

    }

}

==> alg-model-23.03.20-20230320.064819-1-sources.jar: cn/com/duiba/nezha/alg/model/DCVR.java <==
package cn.com.duiba.nezha.alg.model;

import cn.com.duiba.nezha.alg.common.util.AssertUtil;
import cn.com.duiba.nezha.alg.feature.coder.FeatureNewCoder;
import cn.com.duiba.nezha.alg.feature.vo.CodeResult;
import cn.com.duiba.nezha.alg.feature.vo.FeatureMapDo;
import cn.com.duiba.nezha.alg.model.enums.PredictResultType;
import cn.com.duiba.nezha.alg.model.tf.LocalTFModel;
import cn.com.duiba.nezha.alg.model.tf.TFServingClient;
import com.alibaba.fastjson.JSON;
import org.slf4j.LoggerFactory;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class DCVR implements Serializable {
    private static final org.slf4j.Logger logger = LoggerFactory.getLogger(DCVR.class);
    private int PB_MAX_SIZE = 128;

    /**
     * 后端预估模型
     */
    private IModel dCvrModel;
    private IModel coderModel;
    private LocalTFModel dcvrLocalTFModel;

    public LocalTFModel getDcvrLocalTFModel() {
        return dcvrLocalTFModel;
    }

    public void setDcvrLocalTFModel(LocalTFModel dcvrLocalTFModel) {
        this.dcvrLocalTFModel = dcvrLocalTFModel;
    }

    /**
     * 点击率预估深度学习TF-S-Client
     */
    private TFServingClient dcvrServingClient;

    public IModel getDCvrModel() {
        return dCvrModel;
    }

    public void setDCvrModel(IModel bCvrModel) {
        this.dCvrModel = dCvrModel;
    }

    public TFServingClient getDcvrServingClient() {
        return dcvrServingClient;
    }

    public void setDcvrServingClient(TFServingClient dcvrServingClient) {
        this.dcvrServingClient = dcvrServingClient;
    }


    /**
     * @param dcvrModel
     */
    public DCVR(IModel dcvrModel) {
        this.dCvrModel = dcvrModel;
    }

    public DCVR(IModel dCvrModel, IModel coderModel, TFServingClient dcvrServingClient) {
        this.dCvrModel = dCvrModel;
        this.coderModel = coderModel;
        this.dcvrServingClient = dcvrServingClient;
    }

    public DCVR(IModel dCvrModel, IModel coderModel, LocalTFModel dcvrLocalTFModel) {
        this.dCvrModel = dCvrModel;
        this.coderModel = coderModel;
        this.dcvrLocalTFModel = dcvrLocalTFModel;
    }

    /**
     * 预估主接口
     *
     * @param featureMap
     * @return
     * @throws Exception
     */
    public <T> Map<PredictResultType, Map<T, Double>> predictDCvr(Map<T, FeatureMapDo> featureMap) throws Exception {
        Map<PredictResultType, Map<T, Double>> ret = new HashMap<>(PB_MAX_SIZE);

        Map<T, Double> dcvrMap = dCvrModel.predictsNew(featureMap);

        if (AssertUtil.isAllNotEmpty(dcvrMap)) {
            ret.put(PredictResultType.DCVR, dcvrMap);
        } else {
            ret = null;
        }

        return ret;
    }

    public <T> Map<PredictResultType, Map<T, Double>> predictDCvrWithTF(Map<T, FeatureMapDo> featureMap) throws Exception {
        Map<PredictResultType, Map<T, Double>> ret = new HashMap<>(PB_MAX_SIZE);

        Map<T, Double> dcvrMap = coderModel.predictWithTFNew(featureMap, dcvrServingClient);

        if (AssertUtil.isAllNotEmpty(dcvrMap)) {
            ret.put(PredictResultType.DCVR, dcvrMap);
        } else {
            logger.warn(coderModel.getModelId() + ": dcvr fusing");
            dcvrMap = dCvrModel.predictsNew(featureMap);
            if (AssertUtil.isAllNotEmpty(dcvrMap)) {
                ret.put(PredictResultType.DCVR, dcvrMap);
            } else {
                ret = null;
            }
        }
        return ret;
    }

    public <T> Map<PredictResultType, Map<T, Double>> predictDCvrWithLocalTF(Map<T, FeatureMapDo> featureMap) throws Exception {
        Map<PredictResultType, Map<T, Double>> ret = new HashMap<>(PB_MAX_SIZE);

        Map<T, Double> dcvrMap = coderModel.predictWithLocalTFNew(featureMap, dcvrLocalTFModel);

        if (AssertUtil.isAllNotEmpty(dcvrMap)) {
            ret.put(PredictResultType.DCVR, dcvrMap);
        } else {
            logger.warn(coderModel.getModelId() + ": dcvr fusing");
            //dcvr没有降级模型，导致dCvrModel可能会为空
            if(dCvrModel!=null) {
                dcvrMap = dCvrModel.predictsNew(featureMap);
            }
            if (AssertUtil.isAllNotEmpty(dcvrMap)) {
                ret.put(PredictResultType.DCVR, dcvrMap);
            } else {
                ret = null;
            }
        }
        return ret;
    }


    public <T> Map<PredictResultType, Map<T, Double>> predictDCvrAndTF(Map<T, FeatureMapDo> featureMap) throws Exception {
        if (dcvrServingClient != null) {
            return predictDCvrWithTF(featureMap);
        }

        if (dcvrLocalTFModel != null) {
            return predictDCvrWithLocalTF(featureMap);
        }
        return predictDCvr(featureMap);

    }

}
